@@ -1,4 +1,5 @@
 import argparse
+from dataclasses import fields
 import pathlib
 import sys
 from lark import __version__ as lark_version
@@ -6,6 +7,8 @@ from gersemi.configuration import (
     make_configuration,
     make_default_configuration_file,
     Configuration,
+    ListExpansion,
+    indent_type,
 )
 from gersemi.mode import get_mode
 from gersemi.return_codes import SUCCESS, FAIL
@@ -37,28 +40,30 @@ def create_argparser():
         "--check",
         dest="check_formatting",
         action="store_true",
-        help=f"Check if files require reformatting. "
-        f"Return {SUCCESS} when there's nothing to reformat, "
-        f"return {FAIL} when some files would be reformatted",
+        help=f"""
+    Check if files require reformatting.
+    Return {SUCCESS} when there's nothing to reformat.
+    Return {FAIL} when some files would be reformatted.
+            """,
     )
     modes_group.add_argument(
         "-i",
         "--in-place",
         dest="in_place",
         action="store_true",
-        help="Format files in-place",
+        help="Format files in-place.",
     )
     modes_group.add_argument(
         "--diff",
         dest="show_diff",
         action="store_true",
-        help="Show diff on stdout for each formatted file instead",
+        help="Show diff on stdout for each formatted file instead.",
     )
     modes_group.add_argument(
         "--default-config",
         nargs=0,
         action=GenerateConfigurationFile,
-        help="Generate default .gersemirc configuration file",
+        help="Generate default .gersemirc configuration file.",
     )
     modes_group.add_argument(
         "--version",
@@ -75,13 +80,12 @@ def create_argparser():
         help="Show this help message and exit.",
     )
 
+    conf_doc: dict[str, str] = {
+        item.name: item.metadata["description"] for item in fields(Configuration)
+    }
+
     configuration_group = parser.add_argument_group(
-        title="configuration",
-        description="By default configuration is loaded from YAML formatted .gersemirc "
-        "file if it's available. "
-        "This file should be placed in one of the common parent directories of source files. "
-        "Arguments from command line can be used to override parts of that configuration "
-        "or supply them in absence of configuration file.",
+        title="configuration", description=Configuration.__doc__
     )
     configuration_group.add_argument(
         "-l",
@@ -89,26 +93,33 @@ def create_argparser():
         metavar="INTEGER",
         dest="line_length",
         type=int,
-        help=f"Maximum line length in characters [default: {Configuration().line_length}]",
+        help=f"{conf_doc['line_length']} [default: {Configuration.line_length}]",
+    )
+    configuration_group.add_argument(
+        "--indent",
+        metavar="(INTEGER | tabs)",
+        dest="indent",
+        type=indent_type,
+        help=f"{conf_doc['indent']} [default: {Configuration.indent}]",
     )
     configuration_group.add_argument(
         "--unsafe",
         dest="unsafe",
         action="store_true",
-        help="Skip default sanity checks",
+        help=conf_doc["unsafe"],
     )
     configuration_group.add_argument(
         "-q",
         "--quiet",
         dest="quiet",
         action="store_true",
-        help="Skip printing non-error messages to stderr",
+        help=conf_doc["quiet"],
     )
     configuration_group.add_argument(
         "--color",
         dest="color",
         action="store_true",
-        help="If --diff is selected showed diff is colorized",
+        help=conf_doc["color"],
     )
     configuration_group.add_argument(
         "--definitions",
@@ -117,10 +128,28 @@ def create_argparser():
         default=[],
         nargs="+",
         type=pathlib.Path,
-        help="Files or directories containing custom command definitions (functions or macros). "
-        "If only - is provided custom definitions, if there are any, are taken from stdin instead. "
-        "Commands from not deprecated CMake native modules don't have to be provided "
-        "(check https://cmake.org/cmake/help/latest/manual/cmake-modules.7.html)",
+        help=conf_doc["definitions"],
+    )
+    configuration_group.add_argument(
+        "--list-expansion",
+        dest="list_expansion",
+        choices=["favour-inlining", "favour-expansion"],
+        help=f"""
+    {conf_doc['list_expansion']}
+    {" ".join(map(lambda attr: attr.description, ListExpansion))}
+    [default: {Configuration.list_expansion.value}]
+            """,
+    )
+    configuration_group.add_argument(
+        "-w",
+        "--workers",
+        metavar="INTEGER",
+        dest="workers",
+        type=int,
+        help=f"""
+    {conf_doc['workers']}
+    [default: number of CPUs on this system]
+        """,
     )
 
     parser.add_argument(
@@ -128,8 +157,10 @@ def create_argparser():
         metavar="src",
         nargs="*",
         type=pathlib.Path,
-        help="File or directory to format. "
-        "If only - is provided input is taken from stdin instead",
+        help="""
+    File or directory to format.
+    If only `-` is provided, input is taken from stdin instead.
+            """,
     )
 
     return parser
@@ -159,7 +190,7 @@ def main():
     configuration = make_configuration(args)
     mode = get_mode(args)
 
-    sys.exit(run(mode, configuration, args.sources))
+    sys.exit(run(mode, configuration, args.workers, args.sources))
 
 
 if __name__ == "__main__":
