@@ -1,12 +1,11 @@
 from typing import List
 from lark import Tree
 from lark.visitors import Transformer, TransformerChain, Transformer_InPlace
-from gersemi.ast_helpers import contains_line_comment, is_one_of_keywords
+from gersemi.ast_helpers import contains_line_comment, is_one_of_keywords, is_comment
+from gersemi.base_command_invocation_dumper import BaseCommandInvocationDumper
+from gersemi.configuration import Spaces
 from gersemi.types import Nodes
 from gersemi.utils import advance
-from .argument_aware_command_invocation_dumper import (
-    ArgumentAwareCommandInvocationDumper,
-)
 
 
 class IsolateUnaryOperators(Transformer_InPlace):
@@ -21,7 +20,11 @@ class IsolateUnaryOperators(Transformer_InPlace):
         is_one_of_unary_operators = is_one_of_keywords(self.unary_operators)
         for one_behind, current in iterator:
             if is_one_of_unary_operators(one_behind):
-                new_children += [Tree("unary_operation", [one_behind, current])]
+                if is_comment(current):
+                    new_children += [Tree("unary_operation", [one_behind])]
+                    new_children += [current]
+                else:
+                    new_children += [Tree("unary_operation", [one_behind, current])]
                 _, current = advance(iterator, times=1, default=(None, None))
                 if current is None:
                     break
@@ -43,6 +46,9 @@ class IsolateUnaryTests(IsolateUnaryOperators):
         "IS_SYMLINK",
         "IS_ABSOLUTE",
         "DEFINED",
+        "IS_READABLE",
+        "IS_WRITABLE",
+        "IS_EXECUTABLE",
     ]
 
 
@@ -66,6 +72,7 @@ class IsolateBinaryTests(Transformer_InPlace):
         "VERSION_LESS_EQUAL",
         "VERSION_GREATER_EQUAL",
         "IN_LIST",
+        "PATH_EQUAL",
     ]
 
     def arguments(self, children: Nodes) -> Tree:
@@ -96,37 +103,45 @@ class IsolateNotExpressions(IsolateUnaryOperators):
     unary_operators: List[str] = ["NOT"]
 
 
+class IsolateAndExpressions(IsolateUnaryOperators):
+    unary_operators: List[str] = ["AND"]
+
+
+class IsolateOrExpressions(IsolateUnaryOperators):
+    unary_operators: List[str] = ["OR"]
+
+
 def IsolateConditions() -> Transformer:
     return TransformerChain(
-        IsolateUnaryTests(), IsolateBinaryTests(), IsolateNotExpressions()
+        IsolateUnaryTests(),
+        IsolateBinaryTests(),
+        IsolateNotExpressions(),
+        IsolateAndExpressions(),
+        IsolateOrExpressions(),
     )
 
 
-class ConditionSyntaxCommandInvocationDumper(ArgumentAwareCommandInvocationDumper):
-    one_value_keywords = ["AND", "OR"]
-
-    def _format_group(self, group: Nodes) -> str:
-        result = self._try_to_format_into_single_line(group, separator=" ")
-        if result is not None:
-            return result
-
-        keyword, *values = group
-        begin = self.visit(keyword)
-        if len(values) == 0:
-            return begin
-
-        formatted_keys = "\n".join(self.visit(value) for value in values)
-        if contains_line_comment([keyword]):
-            return f"{begin}\n{self._indent(formatted_keys)}"
-        return f"{begin} {formatted_keys.lstrip()}"
+class ConditionSyntaxCommandInvocationDumper(BaseCommandInvocationDumper):
+    inhibit_favour_expansion = True
 
     def unary_operation(self, tree):
         result = self._try_to_format_into_single_line(tree.children, separator=" ")
         if result is not None:
             return result
 
-        operation, arg = tree.children
+        operation, *rest = tree.children
         formatted_operation = self.visit(operation)
+        if len(rest) == 0:
+            return formatted_operation
+
+        arg, *_ = rest
+        if (
+            (not contains_line_comment([operation]))
+            and isinstance(self.indent_type, Spaces)
+            and (len(formatted_operation.strip()) < self.indent_type)
+        ):
+            return f"{formatted_operation} {self.visit(arg).lstrip()}"
+
         with self.indented():
             formatted_arg = self.visit(arg)
         return f"{formatted_operation}\n{formatted_arg}"
@@ -143,6 +158,26 @@ class ConditionSyntaxCommandInvocationDumper(ArgumentAwareCommandInvocationDumpe
             formatted_rhs = self.visit(rhs)
         return f"{formatted_lhs}\n{formatted_operation}\n{formatted_rhs}"
 
-    def arguments(self, tree):
-        preprocessed = IsolateConditions().transform(tree)
-        return super().arguments(preprocessed)
+    def _preprocess_arguments(self, arguments):
+        return IsolateConditions().transform(arguments)
+
+    def _split_arguments(self, arguments):
+        if len(arguments) < 1:
+            return arguments
+
+        head, *tail = arguments
+        return [[head], tail]
+
+    def complex_argument(self, tree):
+        arguments, *_ = tree.children
+        result = self._try_to_format_into_single_line(
+            arguments.children, separator=" ", prefix="(", postfix=")"
+        )
+        if result is not None:
+            return result
+
+        begin = self._indent("(\n")
+        with self.indented():
+            formatted_arguments = self.visit(arguments)
+        end = self._indent(")")
+        return f"{begin}{formatted_arguments}\n{end}"
