@@ -15,6 +15,7 @@ class CTestBuild(ArgumentAwareCommandInvocationDumper):
         "NUMBER_WARNINGS",
         "RETURN_VALUE",
         "CAPTURE_CMAKE_ERROR",
+        "PARALLEL_LEVEL",
     ]
 
 
@@ -63,6 +64,7 @@ class CTestRunScript(ArgumentAwareCommandInvocationDumper):
 
 
 class CTestStart(ArgumentAwareCommandInvocationDumper):
+    front_positional_arguments = ["<model>", "<source>", "<binary>"]
     options = ["APPEND", "QUIET"]
     one_value_keywords = ["GROUP"]
 
@@ -104,6 +106,8 @@ class CTestTest(ArgumentAwareCommandInvocationDumper):
         "STOP_TIME",
         "RETURN_VALUE",
         "CAPTURE_CMAKE_ERROR",
+        "INCLUDE_FROM_FILE",
+        "EXCLUDE_FROM_FILE",
     ]
 
 
