@@ -54,6 +54,17 @@ class CheckPIESupported(ArgumentAwareCommandInvocationDumper):
     multi_value_keywords = ["LANGUAGES"]
 
 
+class CheckSourceCompiles(ArgumentAwareCommandInvocationDumper):
+    front_positional_arguments = ["<lang>", "<code>", "<resultVar>"]
+    one_value_keywords = ["SRC_EXT"]
+    multi_value_keywords = ["FAIL_REGEX"]
+
+
+class CheckSourceRuns(ArgumentAwareCommandInvocationDumper):
+    front_positional_arguments = ["<lang>", "<code>", "<resultVar>"]
+    one_value_keywords = ["SRC_EXT"]
+
+
 class CheckStructHasMember(ArgumentAwareCommandInvocationDumper):
     one_value_keywords = ["LANGUAGE"]
 
@@ -84,6 +95,7 @@ class CMakePrintProprties(ArgumentAwareCommandInvocationDumper):
 
 
 class ConfigurePackageConfigFile(ArgumentAwareCommandInvocationDumper):
+    front_positional_arguments = ["<input>", "<output>"]
     options = ["NO_SET_AND_CHECK_MACRO", "NO_CHECK_REQUIRED_COMPONENTS_MACRO"]
     one_value_keywords = ["INSTALL_DESTINATION", "INSTALL_PREFIX"]
     multi_value_keywords = ["PATH_VARS"]
@@ -244,6 +256,7 @@ class ExternalProjectAdd(CommandLineFormatter, ArgumentAwareCommandInvocationDum
         "CVS_REPOSITORY",
         "CVS_MODULE",
         "CVS_TAG",
+        "DOWNLOAD_EXTRACT_TIMESTAMP",
         # Update/Patch Step
         "UPDATE_DISCONNECTED",
         # Configure Step
@@ -253,9 +266,11 @@ class ExternalProjectAdd(CommandLineFormatter, ArgumentAwareCommandInvocationDum
         "CMAKE_GENERATOR_TOOLSET",
         "CMAKE_GENERATOR_INSTANCE",
         "SOURCE_SUBDIR",
+        "CONFIGURE_HANDLED_BY_BUILD",
         # Build Step
         "BUILD_IN_SOURCE",
         "BUILD_ALWAYS",
+        "BUILD_JOB_SERVER_AWARE",
         # Install Step
         # Test Step
         "TEST_BEFORE_INSTALL",
@@ -274,6 +289,7 @@ class ExternalProjectAdd(CommandLineFormatter, ArgumentAwareCommandInvocationDum
         # Terminal Access
         "USES_TERMINAL_DOWNLOAD",
         "USES_TERMINAL_UPDATE",
+        "USES_TERMINAL_PATCH",
         "USES_TERMINAL_CONFIGURE",
         "USES_TERMINAL_BUILD",
         "USES_TERMINAL_INSTALL",
@@ -303,6 +319,7 @@ class ExternalProjectAdd(CommandLineFormatter, ArgumentAwareCommandInvocationDum
         "BUILD_BYPRODUCTS",
         # Install Step
         "INSTALL_COMMAND",
+        "INSTALL_BYPRODUCTS",
         # Test Step
         "TEST_COMMAND",
         # Output Logging
@@ -365,11 +382,15 @@ class FeatureSummary(ArgumentAwareCommandInvocationDumper):
     one_value_keywords = ["FILENAME", "VAR", "DESCRIPTION", "WHAT"]
 
 
-class SetPackageProperties(ArgumentAwareCommandInvocationDumper):
-    one_value_keywords = ["URL", "DESCRIPTION", "TYPE", "PURPOSE"]
+class SetPackageProperties(
+    KeywordWithPairsFormatter, ArgumentAwareCommandInvocationDumper
+):
+    multi_value_keywords = ["PROPERTIES"]
+    keyword_formatters = {"PROPERTIES": "_format_keyword_with_pairs"}
 
 
 class FetchContentDeclare(CommandLineFormatter, ArgumentAwareCommandInvocationDumper):
+    options = ["SYSTEM", "OVERRIDE_FIND_PACKAGE", "EXCLUDE_FROM_ALL"]
     one_value_keywords = [
         # Download Step
         "URL_HASH",
@@ -405,6 +426,7 @@ class FetchContentDeclare(CommandLineFormatter, ArgumentAwareCommandInvocationDu
         "UPDATE_DISCONNECTED",
     ]
     multi_value_keywords = [
+        "FIND_PACKAGE_ARGS",
         # Download Step
         "DOWNLOAD_COMMAND",
         "URL",
@@ -478,6 +500,11 @@ class FetchContentGetProperties(ArgumentAwareCommandInvocationDumper):
     one_value_keywords = ["SOURCE_DIR", "BINARY_DIR", "POPULATED"]
 
 
+class FetchContentSetPopulated(ArgumentAwareCommandInvocationDumper):
+    front_positional_arguments = ["<name>"]
+    one_value_keywords = ["SOURCE_DIR", "BINARY_DIR"]
+
+
 class FindPackageHandleStandardArgs(ArgumentAwareCommandInvocationDumper):
     options = ["HANDLE_COMPONENTS", "CONFIG_MODE", "NAME_MISMATCHED"]
     one_value_keywords = [
@@ -499,6 +526,35 @@ class FortranCInterfaceHeader(ArgumentAwareCommandInvocationDumper):
     multi_value_keywords = ["SYMBOLS"]
 
 
+class GenerateAppleArchitectureSelectionFile(ArgumentAwareCommandInvocationDumper):
+    front_positional_arguments = ["<filename>"]
+    one_value_keywords = [
+        "INSTALL_DESTINATION",
+        "INSTALL_PREFIX",
+        "SINGLE_ARCHITECTURES",
+        "SINGLE_ARCHITECTURE_INCLUDE_FILES",
+        "UNIVERSAL_ARCHITECTURES",
+        "UNIVERSAL_INCLUDE_FILE",
+    ]
+
+
+class GenerateApplePlatformSelectionFile(ArgumentAwareCommandInvocationDumper):
+    front_positional_arguments = ["<filename>"]
+    one_value_keywords = [
+        "INSTALL_DESTINATION",
+        "INSTALL_PREFIX",
+        "MACOS_INCLUDE_FILE",
+        "IOS_INCLUDE_FILE",
+        "IOS_SIMULATOR_INCLUDE_FILE",
+        "TVOS_INCLUDE_FILE",
+        "TVOS_SIMULATOR_INCLUDE_FILE",
+        "WATCHOS_INCLUDE_FILE",
+        "WATCHOS_SIMULATOR_INCLUDE_FILE",
+        "VISIONOS_INCLUDE_FILE",
+        "VISIONOS_SIMULATOR_INCLUDE_FILE",
+    ]
+
+
 class GenerateExportHeader(ArgumentAwareCommandInvocationDumper):
     options = ["DEFINE_NO_DEPRECATED"]
     one_value_keywords = [
@@ -532,6 +588,7 @@ class GTestDiscoverTests(
     KeywordWithPairsFormatter,
     ArgumentAwareCommandInvocationDumper,
 ):
+    front_positional_arguments = ["<target>"]
     options = ["NO_PRETTY_TYPES", "NO_PRETTY_VALUES"]
     one_value_keywords = [
         "WORKING_DIRECTORY",
@@ -541,6 +598,7 @@ class GTestDiscoverTests(
         "DISCOVERY_TIMEOUT",
         "XML_OUTPUT_DIR",
         "DISCOVERY_MODE",
+        "TEST_FILTER",
     ]
     multi_value_keywords = ["EXTRA_ARGS", "PROPERTIES"]
     keyword_formatters = {
@@ -550,6 +608,7 @@ class GTestDiscoverTests(
 
 
 class AddJar(ArgumentAwareCommandInvocationDumper):
+    options = ["RESOURCES"]
     one_value_keywords = [
         "ENTRY_POINT",
         "VERSION",
@@ -557,8 +616,9 @@ class AddJar(ArgumentAwareCommandInvocationDumper):
         "OUTPUT_DIR",
         "GENERATE_NATIVE_HEADERS",
         "DESTINATION",
+        "BUILD",
     ]
-    multi_value_keywords = ["SOURCES", "INCLUDE_JARS"]
+    multi_value_keywords = ["SOURCES", "INCLUDE_JARS", "NAMESPACE"]
 
 
 class InstallJar(ArgumentAwareCommandInvocationDumper):
@@ -633,8 +693,9 @@ class BisonTarget(ArgumentAwareCommandInvocationDumper):
 
 
 class DoxygenAddDocs(ArgumentAwareCommandInvocationDumper):
+    front_positional_arguments = ["targetName"]
     options = ["ALL", "USE_STAMP_FILE"]
-    one_value_keywords = ["WORKING_DIRECTORY", "COMMENT"]
+    one_value_keywords = ["WORKING_DIRECTORY", "COMMENT", "CONFIG_FILE"]
 
 
 class EnvModule(CommandLineFormatter, ArgumentAwareCommandInvocationDumper):
@@ -685,7 +746,15 @@ class MatlabAddUnitTest(CommandLineFormatter, ArgumentAwareCommandInvocationDump
 
 
 class MatlabAddMex(ArgumentAwareCommandInvocationDumper):
-    options = ["EXECUTABLE", "MODULE", "SHARED", "R2017b", "R2018a", "EXCLUDE_FROM_ALL"]
+    options = [
+        "EXECUTABLE",
+        "MODULE",
+        "SHARED",
+        "R2017b",
+        "R2018a",
+        "EXCLUDE_FROM_ALL",
+        "NO_IMPLICIT_LINK_TO_MATLAB_LIBRARIES",
+    ]
     one_value_keywords = ["NAME", "OUTPUT_NAME", "DOCUMENTATION"]
     multi_value_keywords = ["SRC", "LINK_TO"]
 
@@ -698,9 +767,15 @@ class PkgCheckModules(ArgumentAwareCommandInvocationDumper):
         "NO_CMAKE_ENVIRONMENT_PATH",
         "IMPORTED_TARGET",
         "GLOBAL",
+        "STATIC_TARGET",
     ]
 
 
+class PkgGetVariable(ArgumentAwareCommandInvocationDumper):
+    front_positional_arguments = ["<resultVar>", "<moduleName>", "<varName>"]
+    multi_value_keywords = ["DEFINE_VARIABLES"]
+
+
 class PkgSearchModule(ArgumentAwareCommandInvocationDumper):
     options = [
         "REQUIRED",
@@ -756,6 +831,10 @@ class SquishAddTest(ArgumentAwareCommandInvocationDumper):
     ]
 
 
+class ExternalDataAddTarget(ArgumentAwareCommandInvocationDumper):
+    one_value_keywords = ["SHOW_PROGRESS"]
+
+
 module_command_mapping = {
     # Utility Modules
     "android_add_test_data": AndroidAddTestData,
@@ -769,6 +848,8 @@ module_command_mapping = {
     "check_objcxx_source_compiles": CheckOBJCXXSourceCompiles,
     "check_pie_supported": CheckPIESupported,
     "check_struct_has_member": CheckStructHasMember,
+    "check_source_compiles": CheckSourceCompiles,
+    "check_source_runs": CheckSourceRuns,
     "check_type_size": CheckTypeSize,
     "cmake_add_fortran_subdirectory": CMakeAddFortranSubdirectory,
     "cmake_print_properties": CMakePrintProprties,
@@ -784,14 +865,18 @@ module_command_mapping = {
     "ctest_coverage_collect_gcov": CTestCoverageCollectGCOV,
     "externalproject_add": ExternalProjectAdd,
     "externalproject_add_step": ExternalProjectAddStep,
+    "externaldata_add_target": ExternalDataAddTarget,
     "feature_summary": FeatureSummary,
     "set_package_properties": SetPackageProperties,
     "fetchcontent_declare": FetchContentDeclare,
     "fetchcontent_populate": FetchContentPopulate,
     "fetchcontent_getproperties": FetchContentGetProperties,
+    "fetchcontent_setpopulated": FetchContentSetPopulated,
     "find_package_handle_standard_args": FindPackageHandleStandardArgs,
     "find_package_check_version": FindPackageCheckVersion,
     "fortrancinterface_header": FortranCInterfaceHeader,
+    "generate_apple_architecture_selection_file": GenerateAppleArchitectureSelectionFile,
+    "generate_apple_platform_selection_file": GenerateApplePlatformSelectionFile,
     "generate_export_header": GenerateExportHeader,
     "gtest_add_tests": GTestAddTests,
     "gtest_discover_tests": GTestDiscoverTests,
@@ -818,6 +903,7 @@ module_command_mapping = {
     "matlab_add_unit_test": MatlabAddUnitTest,
     "matlab_add_mex": MatlabAddMex,
     "pkg_check_modules": PkgCheckModules,
+    "pkg_get_variable": PkgGetVariable,
     "pkg_search_module": PkgSearchModule,
     "protobuf_generate_cpp": ProtobufGenerateCpp,
     "qt4_wrap_cpp": Qt4WrapCpp,
