@@ -18,6 +18,10 @@ def flat_split(pattern, string):
     return string[:begin], string[begin:end], string[end:]
 
 
+def split_by_line_comment(string):
+    return flat_split(r"\s*" + LINE_COMMENT_BEGIN, string)
+
+
 def split_by_bracket_arguments(string):
     return flat_split(BRACKET_ARGUMENT_REGEX, string)
 
@@ -27,22 +31,28 @@ def split_by_quoted_arguments(string):
 
 
 def split_into_segments(string):
-    segments = split_by_bracket_arguments(string)
+    head, *comment = split_by_line_comment(string)
+    line_comment = "".join(comment)
+    if '"' in head:
+        head += line_comment
+        line_comment = ""
+    segments = split_by_bracket_arguments(head)
     result = [split_by_quoted_arguments(segment) for segment in segments]
+    result += [[line_comment]]
     return [item for segment in result for item in segment if item != ""]
 
 
-def indent_segment(segment, indent_size):
-    prefix = " " * indent_size
+def indent_segment(segment, indent_symbol):
     if segment[:1] in ["[", '"']:
-        return f"{prefix}{segment}"
-    return indent(segment, prefix)
+        return segment
+    return indent(segment, indent_symbol, lambda s: not s.startswith("\n"))
 
 
-def safe_indent(string, indent_size):
+def safe_indent(string, indent_symbol):
     segments = split_into_segments(string)
-    segment_indenter = lambda segment: indent_segment(segment, indent_size)
-    return "".join(map(segment_indenter, segments))
+    return "".join(
+        map(lambda segment: indent_segment(segment, indent_symbol), segments)
+    )
 
 
 def strip_empty_lines_from_edges(s):
@@ -71,6 +81,16 @@ def ends_with_line_comment(s):
     return find_line_comment_begin(s) != -1
 
 
+def remove_common_beginning(s, other):
+    index = 0
+    for left, right in zip(s, other):
+        if left != right:
+            break
+        index += 1
+
+    return s[index:]
+
+
 class PreservingCommandInvocationDumper(BaseDumper):
     def _preprocess_content(self, content):
         if content.strip() == "":
@@ -86,7 +106,8 @@ class PreservingCommandInvocationDumper(BaseDumper):
         return f"{begin}{stripped_content.rstrip()}{end}"
 
     def custom_command(self, tree):
-        indentation, identifier, _, formatted_arguments = tree.children
+        indentation, raw_identifier, _, formatted_arguments = tree.children
+        identifier = self.format_command_name(raw_identifier)
         begin = self._indent(f"{identifier}(")
         content = formatted_arguments.children[0]
         if content == "":
@@ -99,11 +120,13 @@ class PreservingCommandInvocationDumper(BaseDumper):
         if result is not None:
             return result
 
+        indent_symbol = remove_common_beginning(self.indent_symbol, indentation)
         body = safe_indent(
-            self._preprocess_content(content), self.alignment - len(indentation)
+            self._preprocess_content(content),
+            indent_symbol,
         )
         if not content.startswith("\n"):
-            body = body.lstrip(" ")
+            body = body.lstrip(indent_symbol)
 
         if "\n" not in body:
             end = ")"
