@@ -12,6 +12,9 @@ class IsolateConfigurationTypeAndItem(Transformer_InPlace):
 
     def arguments(self, children):
         new_children = []
+        if len(children) < 2:
+            return Tree("arguments", new_children)
+
         iterator = zip(children, children[1:])
         is_one_of_defined_keywords = is_one_of_keywords(self.keywords)
         for one_behind, current in iterator:
@@ -28,6 +31,7 @@ class IsolateConfigurationTypeAndItem(Transformer_InPlace):
 
 
 class TargetLinkLibraries(ArgumentAwareCommandInvocationDumper):
+    front_positional_arguments = ["<target>"]
     multi_value_keywords = [
         "INTERFACE",
         "PUBLIC",
@@ -44,6 +48,12 @@ class TargetLinkLibraries(ArgumentAwareCommandInvocationDumper):
             formatted_item = self.visit(item)
         return f"{formatted_specifier} {formatted_item}"
 
+    def _split_arguments(self, arguments):
+        preprocessed = IsolateConfigurationTypeAndItem().transform(
+            Tree("arguments", arguments)
+        )
+        return super()._split_arguments(preprocessed.children)
+
     def arguments(self, tree):
         preprocessed = IsolateConfigurationTypeAndItem().transform(tree)
         return super().arguments(preprocessed)
