@@ -1,15 +1,23 @@
 from itertools import chain
 from gersemi.base_dumper import BaseDumper
 from gersemi.command_invocation_dumper import CommandInvocationDumper
+from gersemi.configuration import ListExpansion
 
 
 class Dumper(CommandInvocationDumper, BaseDumper):
-    def __init__(self, width, custom_command_definitions):
+    def __init__(
+        self,
+        width,
+        indent_size,
+        custom_command_definitions,
+        list_expansion=ListExpansion.FavourInlining,
+    ):
         self.custom_command_definitions = custom_command_definitions
-        super().__init__(width)
+        self.list_expansion = list_expansion
+        super().__init__(width, indent_size)
 
     def file(self, tree):
-        result = "{}".format(self.__default__(tree))
+        result = self.__default__(tree)
         if result.endswith("\n"):
             return result
         return result + "\n"
@@ -36,7 +44,7 @@ class Dumper(CommandInvocationDumper, BaseDumper):
         return " ".join(self.visit(child) for child in tree.children)
 
     def line_comment(self, tree):
-        return self._indent("#{}".format("".join(tree.children)))
+        return self._indent(f"#{''.join(tree.children)}")
 
     def preformatted_block(self, tree):
         disable_formatter, *body, enable_formatter = tree.children
