@@ -16,8 +16,11 @@ class Parser:
             "foo([=[foo bar]])",
             "foo([=[foo bar ]==])",
             "foo(foo [=[foo bar ]==] foo)",
+            "foo(foo foo [==[foo]===] foo)",
         ],
         UnbalancedParentheses: [
+            "foo(foo foo",
+            "foo(foo foo # )",
             "foo(bar",
             "foo(bar\n",
             "foo(BAR (BAZ)",
@@ -53,7 +56,7 @@ class Parser:
             exception.get_context(code), exception.line, exception.column
         )
 
-    def parse(self, code):
+    def parse(self, code):  # pylint: disable=inconsistent-return-statements
         try:
             return self.lark_parser.parse(code)
         except UnexpectedInput as u:
