@@ -1,9 +1,9 @@
 from itertools import dropwhile
-import os
 from typing import List
 from lark import Discard, Tree
 from lark.visitors import Transformer_InPlace
 from gersemi.ast_helpers import is_newline
+from gersemi.builtin_commands import BUILTIN_COMMANDS
 from gersemi.types import Nodes
 
 
@@ -21,34 +21,24 @@ class RemoveSuperfluousEmptyLines(Transformer_InPlace):
 
 
 class SimplifyParseTree(Transformer_InPlace):
-    def non_command_element(self, children: Nodes) -> Tree:
+    def non_command_element(self, children: Nodes):
         if len(children) == 0:
-            raise Discard
+            return Discard
         return Tree("non_command_element", children)
 
 
-def get_builtin_commands():
-    HERE = os.path.dirname(os.path.realpath(__file__))
-    is_not_comment_or_empty = lambda s: not (s.startswith("#") or len(s) == 0)
-
-    with open(os.path.join(HERE, "builtin_commands"), "r") as f:
-        return set(filter(is_not_comment_or_empty, f.read().splitlines()))
-
-
 class PreserveCustomCommandFormatting(Transformer_InPlace):
-    builtin_commands = get_builtin_commands()
-
     def __init__(self, code):
         super().__init__()
         self.code = code
 
     def _get_original_formatting(self, lparen, rparen):
-        start, end = lparen.end_pos, rparen.pos_in_stream
+        start, end = lparen.end_pos, rparen.start_pos
         content = self.code[start:end]
         return Tree("formatted_node", [content])
 
     def _get_indentation(self, identifier):
-        end = identifier.pos_in_stream
+        end = identifier.start_pos
         start = end - identifier.column + 1
         return self.code[start:end]
 
@@ -66,7 +56,7 @@ class PreserveCustomCommandFormatting(Transformer_InPlace):
         )
 
     def _is_builtin(self, identifier):
-        return identifier in self.builtin_commands
+        return identifier.lower() in BUILTIN_COMMANDS
 
     def command_invocation(self, children):
         identifier, _, arguments, _ = children
