@@ -8,7 +8,10 @@ import sys
 from typing import Callable, Dict, Iterable, Tuple
 from gersemi.cache import create_cache
 from gersemi.configuration import Configuration
-from gersemi.custom_command_definition_finder import find_custom_command_definitions
+from gersemi.custom_command_definition_finder import (
+    find_custom_command_definitions,
+    get_just_definitions,
+)
 from gersemi.formatter import create_formatter, Formatter
 from gersemi.mode import Mode
 from gersemi.parser import PARSER as parser
@@ -54,10 +57,10 @@ def find_custom_command_definitions_in_file_impl(filepath: Path) -> Dict[str, Ke
     with smart_open(filepath, "r") as f:
         code = f.read()
     if not has_custom_command_definition(code):
-        return dict()
+        return {}
 
     parse_tree = parser.parse(code)
-    return find_custom_command_definitions(parse_tree)
+    return find_custom_command_definitions(parse_tree, filepath)
 
 
 def find_custom_command_definitions_in_file(
@@ -66,10 +69,20 @@ def find_custom_command_definitions_in_file(
     return apply(find_custom_command_definitions_in_file_impl, filepath)
 
 
+def check_conflicting_definitions(definitions):
+    for name, info in definitions.items():
+        if len(info) > 1:
+            print_to_stderr(f"Warning: conflicting definitions for '{name}':")
+            places = sorted(where for _, where in info)
+            for index, where in enumerate(places):
+                kind = "(used)   " if index == 0 else "(ignored)"
+                print_to_stderr(f"{kind} {where}")
+
+
 def find_all_custom_command_definitions(
     paths: Iterable[Path], pool
 ) -> Dict[str, Keywords]:
-    result = dict()
+    result: Dict = {}
 
     files = get_files(paths)
     find = find_custom_command_definitions_in_file
@@ -77,21 +90,28 @@ def find_all_custom_command_definitions(
     for defs in pool.imap_unordered(find, files, chunksize=CHUNKSIZE):
         if isinstance(defs, Error):
             print_to_stderr(get_error_message(defs))
-        else:
-            result.update(defs)
-    return result
+            continue
+
+        for name, info in defs.items():
+            if name in result:
+                result[name].extend(info)
+            else:
+                result[name] = info
+
+    check_conflicting_definitions(result)
+    return get_just_definitions(result)
 
 
 def select_task(mode: Mode, configuration: Configuration):
     return {
         Mode.ForwardToStdout: lambda _: forward_to_stdout,
         Mode.RewriteInPlace: lambda _: rewrite_in_place,
-        Mode.CheckFormatting: lambda config: quiet_check_formatting
-        if config.quiet
-        else check_formatting,
-        Mode.ShowDiff: lambda config: show_colorized_diff
-        if config.color
-        else show_diff,
+        Mode.CheckFormatting: lambda config: (
+            quiet_check_formatting if config.quiet else check_formatting
+        ),
+        Mode.ShowDiff: lambda config: (
+            show_colorized_diff if config.color else show_diff
+        ),
     }[mode](configuration)
 
 
@@ -117,10 +137,10 @@ def consume_task_result(task_result: TaskResult) -> Tuple[Path, int]:
     return path, return_code
 
 
-def create_pool(is_stdin_in_sources):
+def create_pool(is_stdin_in_sources, num_workers):
     if is_stdin_in_sources:
-        return mp_dummy.Pool()
-    return mp.Pool(processes=mp.cpu_count())
+        return mp_dummy.Pool
+    return partial(mp.Pool, processes=num_workers)
 
 
 def filter_already_formatted_files(
@@ -143,12 +163,15 @@ def store_files_in_cache(
         cache.store_files(configuration_summary, files)
 
 
-def run(mode: Mode, configuration: Configuration, sources: Iterable[Path]):
+def run(
+    mode: Mode, configuration: Configuration, num_workers: int, sources: Iterable[Path]
+):
     configuration_summary = configuration.summary()
     requested_files = get_files(sources)
     task = select_task(mode, configuration)
 
-    with create_cache() as cache, create_pool(Path("-") in requested_files) as pool:
+    pool_cm = create_pool(Path("-") in requested_files, num_workers)
+    with create_cache() as cache, pool_cm() as pool:
         files_to_format = list(
             filter_already_formatted_files(
                 cache, configuration_summary, requested_files
@@ -160,7 +183,9 @@ def run(mode: Mode, configuration: Configuration, sources: Iterable[Path]):
         formatter = create_formatter(
             not configuration.unsafe,
             configuration.line_length,
+            configuration.indent,
             custom_command_definitions,
+            configuration.list_expansion,
         )
         execute = partial(run_task, formatter=formatter, task=task)
 
